==> haskell-tls-session-manager-0.0.4-414-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.4
visibility:           public
id:                   tls-session-manager-0.0.4-LaqOvVseTkLDm3IdOdzOuY
key:                  tls-session-manager-0.0.4-LaqOvVseTkLDm3IdOdzOuY
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance

category:             Web
abi:                  748ad13c042620667a6e33d964da3d00
exposed:              True
exposed-modules:      Network.TLS.SessionManager
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.4-LaqOvVseTkLDm3IdOdzOuY
depends:
    auto-update-0.1.6-4raagSfmfWb5OkgS1yIbbW base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-5bOsByOoUdUF7nnek1o8YW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.1-2MX8ieLdASiB2WHK2JtHN8
    tls-1.9.0-76VgS8qK7G5L7J8DOH6btG

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.4-415-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.4
visibility:           public
id:                   tls-session-manager-0.0.4-KH8uDQvlpIhBvIHgOSlyQj
key:                  tls-session-manager-0.0.4-KH8uDQvlpIhBvIHgOSlyQj
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance

category:             Web
abi:                  b983d1530de7af3b5955bd67611e4ede
exposed:              True
exposed-modules:      Network.TLS.SessionManager
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.4-KH8uDQvlpIhBvIHgOSlyQj
depends:
    auto-update-0.1.6-4raagSfmfWb5OkgS1yIbbW base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-5bOsByOoUdUF7nnek1o8YW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.1-2MX8ieLdASiB2WHK2JtHN8
    tls-1.9.0-AS7bS9cnDanI9GCslDgQq2

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
